@@ -1,7 +1,5 @@
 package Exception::Multistate;
-$Exception::Multistate::VERSION = '0.007';
-use qbit;
-
+$Exception::Multistate::VERSION = '0.008';
 use base qw(Exception);
 
-TRUE;
+1;
